@@ -1242,13 +1242,13 @@ bool AAptInterface::processPackageDataLine(Package*& pkg, QByteArray& line)
 	}
 	else if( line.startsWith("Maemo-Display-Name: ") )
 	{
-		pkg->setMaemoDisplayName( line.mid(20) );
+		pkg->setMaemoDisplayName( QString::fromUtf8(line.mid(20)) );
 	}
 
 	if( iMultiLine == MultiLineDesc ) {
 		if( (line.startsWith(' ') || line.startsWith('\t')) && line.trimmed()!="" ) {
 			if( line.trimmed()!="." )
-				pkg->appendDescLong( line.trimmed() + "\n" );
+				pkg->appendDescLong( QString::fromUtf8(line.trimmed()) + "\n" );
 			else
 				pkg->appendDescLong( "\n" );
 		} else {
@@ -1265,7 +1265,7 @@ bool AAptInterface::processPackageDataLine(Package*& pkg, QByteArray& line)
 
 	if( line.startsWith("Description: ") )
 	{
-		pkg->setDescShort( line.mid(13).trimmed() );
+		pkg->setDescShort( QString::fromUtf8(line.mid(13).trimmed()) );
 		iMultiLine = MultiLineDesc;
 	}
 	else if( line.startsWith("Maemo-Icon-26:") )
@@ -1408,7 +1408,7 @@ void AAptInterface::startFetchDates()
 	while (i.hasNext() )
 	{
 		i.next();
-		if( !i.value()->date().isValid() && i.value()->section().startsWith("user/") )
+		if( !i.value()->date().isValid() && i.value()->section().startsWith("user/") && !i.value()->isBlacklisted() )
 		{
 			Repository* repo = 0;
 			for( int x=0; x<i.value()->repositories().count(); x++ )
@@ -1429,7 +1429,7 @@ void AAptInterface::startFetchDates()
 	iDateRequestsReceived = 0;
 	iNetworkError = QNetworkReply::NoError;
 
-	qDebug() << "dates to fetch:" << fetchable.count();
+	qDebug() << "package dates to fetch:" << fetchable.count();
 
 	QHashIterator<QString, Package*> fe( fetchable );
 	while (fe.hasNext() && !iTerminated)
@@ -1454,9 +1454,9 @@ void AAptInterface::startFetchDates()
 
 			if( repo )
 			{
-				//qDebug() << "getting date for" << fe.value()->name();
-
 				url = repo->url() + repo->dir() + fe.value()->fileNameFull();
+
+				//qDebug() << "getting date for" << fe.value()->name();
 				//qDebug() << url;
 
 				QUrl u(url);
@@ -1480,18 +1480,6 @@ void AAptInterface::startFetchDates()
 					iDateRequestsSent++;
 					iDateRequestsWaiting++;
 				}
-
-				/*QNetworkReply* reply = nam->head(r);
-
-				while(reply->isRunning()) {
-					QApplication::processEvents(QEventLoop::WaitForMoreEvents);
-				}
-
-				//qDebug() << "reply" << reply->header(QNetworkRequest::LastModifiedHeader).toDateTime();
-				if( reply->header(QNetworkRequest::LastModifiedHeader).toDateTime().isValid() )
-					fe.value()->setDate( reply->header(QNetworkRequest::LastModifiedHeader).toDateTime() );
-
-				delete reply;*/
 			}
 			count = iDateRequestsReceived;
 			updProgress++;
@@ -1524,7 +1512,6 @@ void AAptInterface::startFetchDates()
 	iCanCancel = false;
 
 	if( iUiDimmer ) {
-		iUiDimmer->updateText("Writing date cache");
 		iUiDimmer->setProgress(100);
 		QApplication::processEvents();
 	}
@@ -1532,8 +1519,13 @@ void AAptInterface::startFetchDates()
 	qDebug() << "sent" << iDateRequestsSent << "requests, received" << iDateRequestsReceived << "replies with"
 			<< iDateRequestErrors << "errors";
 
-	logToFile( QString("Finished fetching package dates, writing cache") );
-	writeDateCache();
+	logToFile( QString("Finished fetching package dates") );
+
+	if( fetchable.count()>0 ) {
+		iUiDimmer->updateText("Writing date cache");
+		QApplication::processEvents();
+		writeDateCache();
+	}
 
 	if( iUiDimmer ) {
 		iUiDimmer->updateText("Creating package view");
