@@ -22,6 +22,7 @@
 
 #include <QtGui>
 #include <QtNetwork>
+#include "blacklistselect.h"
 
 const QString KLogFileDir = "/root/.fapman";
 const QString KLogFileName = "/root/.fapman/lastlog.txt";
@@ -68,6 +69,10 @@ public:
 	void readRepositoryInfo();
 	bool writeRepositories();
 	bool needRepoRefresh();
+	void removeFromBlacklist(Package* pkg, BlacklistSelect::blackList oldstate);
+	void writeBlacklist();
+
+	bool dateCacheExists();
 
 private:
 	void runNext();
@@ -93,6 +98,10 @@ private:
 	Package* ReadNextPackage(QFile& f, quint64& currentreaddata);
 	bool processPackageDataLine(Package*& pkg, QByteArray& line);
 
+	void readBlacklist();
+	void writeDateCache();
+	void readDateCache();
+
 private slots:
 	void errorAptGetUpdate(QProcess::ProcessError error);
 	void errorAptGetSimulate(QProcess::ProcessError error);
@@ -108,6 +117,8 @@ private slots:
 	void uiUpdaterAptGetInstall();
 	void progressCheckTimerCallback();
 
+	void dateFetchNetworkReply(QNetworkReply* reply);
+
 private:
 	QHash<QString, Package*> iPackagesAvailable;
 	QHash<QString, Package*> iPackagesInstalled;
@@ -150,7 +161,15 @@ private:
 	int iCatalogCounter;
 	int iCatalogsTotal;
 
+	QStringList iBlacklist;
+
 	multiLine iMultiLine;
+
+	int iDateRequestsWaiting;
+	int iDateRequestsSent;
+	int iDateRequestsReceived;
+	int iDateRequestErrors;
+	QNetworkReply::NetworkError iNetworkError;
 };
 
 
