@@ -35,6 +35,7 @@ dimmer::dimmer(QWidget *parent) :
 	iAnimDir = 1;
 	iAnimY = this->rect().height()-this->rect().height()/4;
 	iProgress = -1;
+	iUpdateAnim = false;
 
 	iTimer = new QTimer(this);
 	connect(iTimer,SIGNAL(timeout()),this,SLOT(timerEvent()));
@@ -63,11 +64,13 @@ void dimmer::paintEvent(QPaintEvent *)
 							iAnimY), 10, 10);
 	}
 
-	iAnim += iAnimDir;
-	if( iAnim>animMax )
-		iAnimDir=-1;
-	if( iAnim==-1 )
-		iAnimDir=1;
+	if( iUpdateAnim ) {
+		iAnim += iAnimDir;
+		if( iAnim>animMax )
+			iAnimDir=-1;
+		if( iAnim==-1 )
+			iAnimDir=1;
+	}
 
 	if( iProgress >= 0 ) {
 		if( iProgress>100 )
@@ -84,7 +87,9 @@ void dimmer::paintEvent(QPaintEvent *)
 
 void dimmer::timerEvent()
 {
+	iUpdateAnim = true;
 	repaint(0,iAnimY-10,rect().width(),22);
+	iUpdateAnim = false;
 }
 
 void dimmer::resizeEvent(QResizeEvent *)
