@@ -18,6 +18,7 @@
 */
 
 #include <QtGui/QApplication>
+#include <iostream>
 #include "mainwindow.h"
 #include "confirmdialog.h"
 
@@ -25,10 +26,29 @@
 #include <unistd.h>
 #endif
 
+bool EnableDebugOutput = false;
+
+void myMessageOutput( QtMsgType, const char *msg )
+{
+	if( EnableDebugOutput )
+		std::cerr << msg << std::endl;
+}
+
 int main(int argc, char *argv[])
 {
+	qInstallMsgHandler( myMessageOutput );
     QApplication a(argc, argv);
-    MainWindow w;
+
+	EnableDebugOutput = false;
+	if( a.arguments().count() >= 2 ) {
+		if( a.arguments().at(1) == "-d" ) {
+			EnableDebugOutput = true;
+			qDebug() << "Enabled debug output";
+		}
+	}
+
+    MainWindow w;	
+
 #if defined(Q_WS_S60)
     w.showMaximized();
 #else
@@ -39,10 +59,11 @@ int main(int argc, char *argv[])
 	uid_t userUID = getuid();
 	if( userUID != 0 ) {
 		ConfirmDialog d(false, &w);
-		d.setText("Warning", "You are not running the application as root. It won't' work as intended.");
+		d.setText("Warning", "You are not running the application as root. It won't work as intended.");
 		d.exec();
 	}
 #endif
 
     return a.exec();
 }
+
