@@ -266,9 +266,9 @@ void MainWindow::operationQueueFinished(QList<AAptInterface::interfaceMode> last
 				if( remvver.count()>i ) {
 					pkglist += " " + remvver.at(i);
 					if( pkg && remvver.at(i) != pkg->version() ) {
-						qDebug() << "Version mismatch, database version is" << pkg->version() << "but installing" << remvver.at(i);
+						qDebug() << "Version mismatch, database version is" << pkg->version() << "but removing" << remvver.at(i);
 						mismatch = true;
-						pkglist += " <font color=\"red\">***TRYING TO INSTALL " + pkg->version() + "***</font> ";
+						pkglist += " <font color=\"red\">***TRYING TO REMOVE " + pkg->version() + "***</font> ";
 					}
 				}
 				if( pkg && pkg->installedSize()>0 )
@@ -374,7 +374,9 @@ void MainWindow::on_actionAbout_triggered()
 	ConfirmDialog d(false, this);
 	d.setText("About","Faster Application Manager<br>"
 			  "<font size=\"-1\">Version " + PROGRAM_VERSION + "</font><br><br>"
-			  "(C) Heikki Holstila 2010");
+			  "(C) Heikki Holstila 2010<br>Donate using "
+			  "<a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=6ZKRY5QFHL42A&lc=FI&item_name=Faster%20Application%20Manager"
+			  "%20for%20Maemo5&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted\">PayPal</a>");
 	d.exec();
 }
 
