@@ -213,7 +213,7 @@ void PackageSelector::on_pushButton_blacklist_clicked()
 	BlacklistSelect::blackList old = iPkg->blacklisted();
 	if( s.exec() ) {
 		updateHeader2();
-		if( !iPkg->isBlacklisted() && old != iPkg->blacklisted() ) {
+		if( old != iPkg->blacklisted() ) {
 			iAptInterface->removeFromBlacklist(iPkg, old);
 			iAptInterface->writeBlacklist();
 		}
