@@ -37,6 +37,9 @@ PackageListWidgetItem::PackageListWidgetItem(Package* p_, QString name_) : QList
 
 void ListItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
+	//QTime t;
+	//t.start();
+
 	QString name = index.data(UserRoleName).toString();
 	QString version = index.data(UserRoleVersion).toString();
 	QString desc = index.data(UserRoleDescShort).toString();
@@ -58,7 +61,6 @@ void ListItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
 	gradientBase.setColorAt(1, base2);
 
 	painter->fillRect(r, gradientBase);
-
 	painter->drawLine(QPoint(r.left(),r.bottom()), QPoint(r.right(),r.bottom()));
 
 	QPixmap icon = index.data(Qt::DecorationRole).value<QPixmap>();
@@ -120,6 +122,9 @@ void ListItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
 	painter->drawPixmap(r.right()-statusicon.width()-2, r.top()+4, 24, 24, statusicon);
 
 	painter->restore();
+
+	//if( t.elapsed()>=100 )
+	//qDebug() << name << t.elapsed();
 }
 
 void ListItemDelegate::loadIcons()
@@ -214,6 +219,17 @@ PackageView::PackageView(QWidget *parent) : QMainWindow(parent), ui(new Ui::Pack
 	ui->listWidget->installEventFilter(iKeyFilter);
 
 	iSortNoticeShown = false;
+
+	// fine-tune kinetic scrolling parameters
+	QAbstractKineticScroller* listscroller = ui->listWidget->property("kineticScroller").value<QAbstractKineticScroller*>();
+	if( listscroller )
+	{
+		//qDebug() << listscroller->dragInertia() << listscroller->decelerationFactor()
+		//		<< listscroller->minimumVelocity() << listscroller->maximumVelocity();
+		listscroller->setDecelerationFactor(0.75); // default is 0.85
+		listscroller->setDragInertia(0.60);	// default is 0.85
+		listscroller->setMaximumVelocity(1800); // default is 3500
+	}
 }
 
 PackageView::~PackageView()
@@ -273,7 +289,7 @@ QString PackageView::generateSortString(Package* pkg)
 		if( !upg && pkg->date().isValid() )
 			sortstr = pkg->date().toString("yyyy-MM-dd hh:mm");
 		else if( upg && upg->date().isValid() ) {
-			sortstr = pkg->date().toString("yyyy-MM-dd hh:mm");
+			sortstr = upg->date().toString("yyyy-MM-dd hh:mm");
 		} else {
 			sortstr = "";
 			iPackagesEmptySort++;
@@ -381,7 +397,7 @@ void PackageView::openWin()
 		iListCoverLabel->show();
 	}
 
-	if( ui->listWidget->count()>0 && iPackagesEmptySort == ui->listWidget->count() && !iSortNoticeShown ) {
+	if( ui->listWidget->count()>1 && iPackagesEmptySort == ui->listWidget->count() && !iSortNoticeShown ) {
 		ConfirmDialog d(false, this);
 		d.setText("Notice", "No shown packages currently have the required information for sorting by this criterion. The list is unsorted.");
 		d.exec();
